.. _api_ref:

=============
API Reference
=============


:mod:`pysal.lib`: PySAL Core 
=============================

* `cg: Computational Geometry <https://pysal.org/libpysal/api.html#cg-computational-geometry>`_
* `examples: Example datasets <https://pysal.org/libpysal/api.html#io>`_
* `graph: Graph class encoding spatial weights matrices <https://pysal.org/libpysal/api.html#graph>`_
* `io: Input-Output <https://pysal.org/libpysal/api.html#io>`_ 
* `weights: Spatial Weights <https://pysal.org/libpysal/api.html#spatial-weights>`_

:mod:`pysal.explore`: Exploratory Spatial Data Analysis
=======================================================
* `esda: Spatial Autocorrelation Analysis <https://pysal.org/esda/api.html>`_
* `giddy: Geospatial Distribution Dynamics <https://pysal.org/giddy/api.html>`_
* `inequality: Spatial Inequality Analysis <https://pysal.org/inequality/api.html>`_
* `momepy: Urban Morphology Measuring Toolkit <http://docs.momepy.org/en/stable/api.html>`_
* `pointpats: Planar Point Pattern Analysis <http://pysal.org/pointpats/api.html>`_
* `segregation: Segregation Analysis <https://pysal.org/segregation/api.html>`_
* `spaghetti: Spatial Analysis on Networks <https://pysal.org/spaghetti/api.html>`_


:mod:`pysal.model`: Spatial Statistical Models
==============================================
* `access: Spatial Accessibility  <https://access.readthedocs.io/en/latest/api.html>`_
* `mgwr: Multiscale Geographically Weighted Regression <https://mgwr.readthedocs.io/en/latest/api.html>`_ 
* `spglm: Sparse Generalized Linear Models <https://spglm.readthedocs.io/en/latest/api.html>`_
* `spint: Spatial Interaction Modeling <https://spint.readthedocs.io/en/latest/api.html>`_
* `spopt: Spatial Optimization <https://pysal.org/spopt/api.html>`_
* `spreg: Spatial Regression and Econometrics <https://spreg.readthedocs.io/en/latest/api.html>`_
* `tobler: Areal Interpolation and Dasymetric Mapping <https://pysal.org/tobler/api.html>`_

:mod:`pysal.viz`: Geovisualization
==================================
* `mapclassify: Choropleth Map Classification Schemes <https://pysal.org/mapclassify/api.html>`_
* `splot: Lightweight Visualization Interface for PySAL Analytics <https://splot.readthedocs.io/en/latest/api.html#>`_

